{ pkgs }:

let
  zshCurried = import ../programs/zsh.nix { inherit pkgs; };
in

{ pkgs
, config
, ... }:

let
  # gitpkgs = import /home/steveej/src/github/NixOS/nixpkgs {};
  unstablepkgs = import <channels-nixos-unstable> { config = config.nixpkgs.config; };
  masterpkgs = import <nixpkgs-master> { config = config.nixpkgs.config; };

in {
  imports = [
    ../profiles/common.nix
    ../profiles/qtile-desktop.nix
    ../profiles/dotfiles.nix
    ../programs/firefox.nix
    ../programs/chromium.nix
    # FIXME: fix homeshick when no WAN connection is available
    # ../programs/homeshick.nix
    ../programs/libreoffice.nix
    ../programs/neovim.nix
    ../programs/pass.nix
    zshCurried
    ../programs/podman.nix
    ../programs/vscode
  ];

  nixpkgs.config = {
    pidgin = {
      openssl = true;
      gnutls = true;
    };

    packageOverrides = pkgs: with pkgs; {
    };
  };

  home.sessionVariables = {
    # TODO: find a way to prevent using a store path for the current file
    # HM_CONFIG_PATH=builtins.toString "${./.}";
    HM_CONFIG="graphical-fullblown";

    GOPATH="$HOME/src/go";

    PATH=pkgs.lib.concatStringsSep ":" [
      "$HOME/.local/bin"
      "$PATH"
    ];
  };

  home.packages = []
    ++ (with pkgs; [
      # Authentication
      cacert
      fprintd
      openssl
      mkpasswd

      # Nix package related tools
      patchelf
      nix-index
      nox
      nix-prefetch-scripts
      nix-prefetch-github

      # Version Control Systems
      pijul
      gitless
      gitRepo
      git-lfs

      # Process/System Administration
      htop
      gnome.gnome-tweaks
      xorg.xhost
      dmidecode
      evtest

      # Archive Managers
      sshfs-fuse
      xarchive
      p7zip
      zip
      unzip
      gzip
      lzop

      # Password Management
      gnupg
      yubikey-manager
      yubikey-manager-qt
      yubikey-personalization
      yubikey-personalization-gui
      gnome.gnome-keyring
      gnome.seahorse

      # Language Support
      hunspellDicts.en-us
      hunspellDicts.de-de

      # Messaging/Communication
      signal-desktop
      pidgin
      hexchat
      aspellDicts.en
      aspellDicts.de
      skypeforlinux
      unstablepkgs.jitsi-meet-electron
      unstablepkgs.zoom-us
      thunderbird
      evolution # gnome4.glib_networking
      unstablepkgs.kotatogram-desktop
      gnome.cheese
      discord

      # Virtualization
      virtmanager
      # (pkgs.lib.hiPrio qemu)
      # virtualbox
      # vagrant
      # docker_compose
      # unstablepkgs.kubernetes
      # unstablepkgs.minikube
      # unstablepkgs.openshift
      # (unstablepkgs.minikube.overrideAttrs (oldAttrs: {
      #   patches = oldAttrs.patches ++ [
      #     (builtins.fetchurl { url ="https://patch-diff.githubusercontent.com/raw/kubernetes/minikube/pull/2517.diff"; })
      #   ];
      # }))
      appimage-run


      # Remote Control Tools
      remmina
      freerdp
      teamviewer

      # Audio/Video Players
      ffmpeg
      vlc
      audacity
      spotify
      youtube-dl-light
      libwebcam

      # Network Tools
      openvpn
      tcpdump
      iftop
      iperf
      bind
      socat
      # 2019-03-05: broken on 19.03 linssid
      iptraf-ng
      ipmitool

      # samba
      iptables
      nftables
      wireshark

      # Code Editors
      # unstablepkgs.atom
      xclip
      xsel

      # Image/Graphic/Design Tools
      gnome.eog
      gimp
      imagemagick
      exiv2
      graphviz
      inkscape
      # barcode
      qrencode
      zbar
      feh
      # digikam


      # Modelling Tools
      # plantuml
      # umlet
      # staruml
      # eclipses.eclipse-modeling
      # dia
      # astah-community

      # Misc Development Tools
      qrcode
      # travis
      jq
      # prometheus
      cdrtools

      # Document Processing and Management
      # zathura
      mendeley
      # zotero
      pandoc
      unstablepkgs.logseq

      # has an EOL version of electron
      # obsidian

      # LaTeX
      perlPackages.YAMLTiny
      perlPackages.FileHomeDir
      perlPackages.UnicodeLineBreak
      (texlive.combine {
        inherit (texlive)
          scheme-small
          texlive-de
          texlive-en
          texlive-scripts
          collection-langgerman

          latexindent
          latexmk

          algorithms
          cm-super

          preprint
          enumitem
          draftwatermark
          everypage
          ulem
          placeins
          minted ifplatform fvextra xstring framed
          ;
      })

      pdftk
      # broken as of 2021-04-24
      # masterpdfeditor

      # File Synchronzation
      # seafile-client
      # grive2
      dropbox
      rsync

      # Filesystem Tools
      ntfs3g
      ddrescue
      ncdu
      woeusb
      unetbootin
      pcmanfm
      hdparm
      testdisk
      binwalk
      gptfdisk
      gparted
      smartmontools

      ## Android
      androidenv.androidPkgs_9_0.platform-tools

      ## Python
      myPython

      # Code generators
      # unstablepkgs.swagger-codegen

      # Misc Desktop Tools
      # TODO: this may be required if brightness control isn't working
      # brightnessctl
      ltunify
      # solaar # TODO: conflicts with solar over udev rules
      dex
      # kitty
      busyboxStatic
      xorg.xbacklight
      coreutils
      lsof
      x11_ssh_askpass
      xdotool
      xdg_utils
      xdg-user-dirs
      dconf
      picocom
      glib.dev # contains gdbus tool
      alacritty
      unstablepkgs.wally-cli
      man-pages

      # Screen recording
      # gtk-recordmydesktop # can't select the window
      # qt-recordmydesktop
      # vokoscreen
      # shutter
      # kazam # doesn't start
      # xvidcap # doesn't keep the recording rectangle
      obs-studio
      screenkey
      # shotcut
      # openshot-qt

      unstablepkgs.ledger-live-desktop
  ]);
}
